Settings

Struct Settings 

pub struct Settings {
    pub confguard_base_dir: String,
    pub guarded: String,
    pub version: i64,
    pub sops: Option<SopsConfig>,
}

Fields

confguard_base_dir: Stringguarded: Stringversion: i64sops: Option<SopsConfig>

Implementations

Source

impl Settings

pub fn new() -> Result<Self, ConfigError>

Creates a new Settings instance with values from config sources

pub fn global() -> &'static RwLock<Settings>

Gets a reference to the global settings: Create it

pub fn read_global() -> RwLockReadGuard<'static, Settings>

Provides shared read access to the global settings

pub fn update_global( new_settings: Settings, ) -> Result<(), PoisonError<RwLockWriteGuard<'static, Settings>>>

Updates the global settings with exclusive write access

pub fn reload() -> Result<(), ConfigError>

Force a reload of the settings from the environment

pub fn load_sops_config(&mut self, config_path: &Path) -> ConfGuardResult<()>