pub struct Settings {
pub confguard_base_dir: String,
pub guarded: String,
pub version: i64,
pub sops: Option<SopsConfig>,
}Fields
confguard_base_dir: Stringguarded: Stringversion: i64sops: Option<SopsConfig>Implementations
Sourceimpl Settings
impl Settings
Sourcepub fn new() -> Result<Self, ConfigError>
pub fn new() -> Result<Self, ConfigError>
Creates a new Settings instance with values from config sources
Sourcepub fn global() -> &'static RwLock<Settings>
pub fn global() -> &'static RwLock<Settings>
Gets a reference to the global settings: Create it
Sourcepub fn read_global() -> RwLockReadGuard<'static, Settings>
pub fn read_global() -> RwLockReadGuard<'static, Settings>
Provides shared read access to the global settings
Sourcepub fn update_global(
new_settings: Settings,
) -> Result<(), PoisonError<RwLockWriteGuard<'static, Settings>>>
pub fn update_global( new_settings: Settings, ) -> Result<(), PoisonError<RwLockWriteGuard<'static, Settings>>>
Updates the global settings with exclusive write access
Sourcepub fn reload() -> Result<(), ConfigError>
pub fn reload() -> Result<(), ConfigError>
Force a reload of the settings from the environment
pub fn load_sops_config(&mut self, config_path: &Path) -> ConfGuardResult<()>